has_no_earlier_match

Function has_no_earlier_match 

pub(super) fn has_no_earlier_match(
    concat_prefix: &Hir,
    literals: &[Literal],
) -> bool
Returns true when it’s impossible for an earlier match to be detected after a literal candidate (corresponding to anything in literals) has been found.

Specifically, that there is no earlier match than what a reverse scan of concat_prefix after a match of literals reports.

Since this requires a single Hir, this implies the reverse inner optimization only works with a single regex.