InnerPrefilter

Struct InnerPrefilter 

pub(crate) struct InnerPrefilter {
    pub(crate) prefix: Hir,
    pub(crate) pre: Prefilter,
    pub(crate) literals: Vec<Literal>,
}
This attempts to extract an “inner” prefilter from the given HIR expressions. If one was found, then a concatenation of the HIR expressions that precede it is returned.

The idea here is that the prefilter returned can be used to find candidate matches. And then the HIR returned can be used to build a reverse regex matcher, which will find the start of the candidate match. Finally, the match still has to be confirmed with a normal anchored forward scan to find the end position of the match.

Note that this assumes leftmost-first match semantics, so callers must not call this otherwise.

Fields

prefix: Hirpre: Prefilter

The prefilter generated from literals.

literals: Vec<Literal>

The actual literals extracted and used to build pre.

These are used by the meta strategy to prove that the inner prefilter can return after the first confirmed candidate. If that proof fails, we could try extracting a different set of literals. But we don’t currently do that.

Implementations

Source

impl InnerPrefilter

pub(crate) fn new(hirs: &[&Hir]) -> Option<InnerPrefilter>